ButtR-package: ButtR: Downloading the OzButterflies Database

ButtR-packageR Documentation

ButtR: Downloading the OzButterflies Database

Description

ButtR is an R package designed to simplify the download and extraction of the OzButterflies Database, a comprehensive dataset containing reflectance spectra, calibrated photographs, and CO1 sequences of Australian butterflies (Reference).

Details

The package includes the function get_Oz_butterflies, which allows users to download specific subsets of the database by applying multiple filters (parameters), providing tailored access to the data based on user-defined criteria.

Author(s)

Maintainer: Diogo Silva diogojackson@hotmail.com (ORCID)

Authors:


ButtR documentation built on April 22, 2026, 1:07 a.m.