Oz_butterflies_summary: Summarise contents of the locally installed OzButterflies...

View source: R/summarise.R

Oz_butterflies_summaryR Documentation

Summarise contents of the locally installed OzButterflies database

Description

Summarise contents of the locally installed OzButterflies database

Usage

Oz_butterflies_summary(
  save_folder = "OzButterflies",
  imgExt = "\\.DNG$|\\.dng$|\\.ARW$|\\.arw$"
)

Arguments

save_folder

Path of folder that contains the OzButterflies database.

imgExt

Regular expression used to identify files to be counted as images. Default is .DNG or .ARW files which are the RGB and UV photos of specimens. DNG is the Adobe open Digital Negative format and used in version 4 (and above) of the database, while ARW is the Sony raw file format, and used in versions 1, 2 and 3.

Value

Data frame with 1 row and columns that summarise the database contents. All summary statistics, apart from the Images count, describe the entire database, regardless of whether the entire database or a subset is installed locally.


ButtR documentation built on April 22, 2026, 1:07 a.m.