| ButtR-package | R Documentation |
ButtR is an R package designed to simplify the download and extraction
of the OzButterflies Database, a comprehensive dataset containing
reflectance spectra, calibrated photographs, and CO1 sequences of Australian butterflies (Reference).
The package includes the function get_Oz_butterflies, which allows users to download
specific subsets of the database by applying multiple filters (parameters), providing
tailored access to the data based on user-defined criteria.
Maintainer: Diogo Silva diogojackson@hotmail.com (ORCID)
Authors:
Jim McLean jim_mclean@optusnet.com.au (ORCID)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.