| Oz_butterflies_summary | R Documentation |
Summarise contents of the locally installed OzButterflies database
Oz_butterflies_summary(
save_folder = "OzButterflies",
imgExt = "\\.DNG$|\\.dng$|\\.ARW$|\\.arw$"
)
save_folder |
Path of folder that contains the OzButterflies database. |
imgExt |
Regular expression used to identify files to be counted as
images. Default is |
Data frame with 1 row and columns that summarise the database
contents. All summary statistics, apart from the Images count, describe
the entire database, regardless of whether the entire database or a subset
is installed locally.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.